@@ -46,15 +46,14 @@ References:
 .. [14] Unden (1997)
 
 """
-
-
 import logging
 import warnings
+from io import BytesIO
 from typing import Iterable, List, Optional, Set, Tuple, Union
 
 import numpy as np
 import pandas as pd
-import quilt
+import pkg_resources
 from equilibrator_cache import FARADAY, Q_, Compound, CompoundCache, R, Reaction
 from equilibrator_cache.exceptions import (
     MissingDissociationConstantsException,
@@ -63,8 +62,9 @@ from equilibrator_cache.exceptions import (
 from equilibrator_cache.reaction import (
     create_stoichiometric_matrix_from_reactions,
 )
+from equilibrator_cache.zenodo import get_cached_filepath
 
-from . import DEFAULT_QUILT_PKG
+from . import ZENODO_DOI_GROUPS, ZENODO_DOI_TRAINING_DATA
 
 
 logger = logging.getLogger(__name__)
@@ -76,11 +76,6 @@ class TrainingData(object):
     def __init__(
         self,
         ccache: CompoundCache,
-        package: Optional[str] = DEFAULT_QUILT_PKG,
-        hash: str = None,
-        version: str = None,
-        tag: str = "latest",
-        force: bool = True,
         override_ionic_strength: Optional[Q_] = None,
         override_temperature: Optional[Q_] = None,
         override_p_mg: Optional[Q_] = None,
@@ -92,17 +87,6 @@ class TrainingData(object):
         ----------
         ccache : CompoundCache
             The compound cache used for looking up structures and pKas.
-        package : str, optional
-            The quilt data package used to initialize the compound cache.
-        hash : str, optional
-            The quilt hash (Default value = None
-        version : str, optional
-            The quilt version (Default value = None)
-        tag : str, optional
-            The quilt tag (Default value = "latest")
-        force : bool, optional
-            Re-download the quilt data if a newer version exists
-            (Default value = True).
         override_ionic_strength : bool, optional
             If provided, overrides all ionic_strength values given in the data
             files with this value.
@@ -117,18 +101,11 @@ class TrainingData(object):
         self.ccache = ccache
         self.S = None  # a DataFrame containing the stoichiometric matrix
 
-        if package is not None:
-            logger.info(f"Loading data from quilt package: {package}")
-            quilt.install(
-                package=package,
-                hash=hash,
-                version=version,
-                tag=tag,
-                force=force,
-            )
-            self.quilt_pkg = quilt.load(package)
-        else:
-            self.quilt_pkg = None
+        # read the group summary table from Zenodo
+        group_file = get_cached_filepath(
+            zenodo_doi=ZENODO_DOI_GROUPS, zenodo_fname="group_summary.csv"
+        )
+        self.group_summary = pd.read_csv(group_file, index_col=0)
 
         logger.info("Gathering reaction data")
         (
@@ -373,7 +350,11 @@ class ToyTrainingData(TrainingData):
 
     def create_reaction_dataframe(self) -> Tuple[pd.DataFrame, Set[Compound]]:
         """Create the DataFrame of reactions for training."""
-        reaction_df = self.quilt_pkg.data.toy_training_data().copy()
+        reaction_df = pd.read_csv(
+            pkg_resources.resource_filename(
+                "component_contribution.data", "toy_training_data.csv"
+            )
+        )
 
         # convert the formula strings into Reaction objects
         reaction_df.loc[:, "reaction"] = reaction_df.reaction.apply(
@@ -397,20 +378,32 @@ class ToyTrainingData(TrainingData):
 class FullTrainingData(TrainingData):
     """Full training data class."""
 
-    def __init__(self, **kw):
+    def __init__(self, ccache: CompoundCache, **kw):
         """Create the FullTrainingData object."""
-        super(FullTrainingData, self).__init__(**kw)
+        super(FullTrainingData, self).__init__(ccache=ccache, **kw)
 
     def create_reaction_dataframe(self) -> Tuple[pd.DataFrame, Set[Compound]]:
         """Create the DataFrame of reactions for training."""
-
-        tecr_df = self.read_tecrdb()
+        tecr_df = self.read_tecrdb(
+            get_cached_filepath(
+                zenodo_doi=ZENODO_DOI_TRAINING_DATA, zenodo_fname="TECRDB.csv"
+            )
+        )
         tecr_df["weight"] = 1.0
 
-        formation_df, non_decomposable_compounds = self.read_formations()
+        formation_df, non_decomposable_compounds = self.read_formations(
+            get_cached_filepath(
+                zenodo_doi=ZENODO_DOI_TRAINING_DATA,
+                zenodo_fname="formation_energies_transformed.csv",
+            )
+        )
         formation_df["weight"] = 1.0
 
-        redox_df, more_non_decomposable_compounds = self.read_redox()
+        redox_df, more_non_decomposable_compounds = self.read_redox(
+            get_cached_filepath(
+                zenodo_doi=ZENODO_DOI_TRAINING_DATA, zenodo_fname="redox.csv"
+            )
+        )
         redox_df["weight"] = 1.0
         non_decomposable_compounds.update(more_non_decomposable_compounds)
 
@@ -419,7 +412,7 @@ class FullTrainingData(TrainingData):
 
         return reaction_df, non_decomposable_compounds
 
-    def read_tecrdb(self) -> pd.DataFrame:
+    def read_tecrdb(self, tecr_file: BytesIO) -> pd.DataFrame:
         """Load a data frame with information from the TECRdb (NIST).
 
         The component-contribution package distributes data tables with
@@ -438,7 +431,7 @@ class FullTrainingData(TrainingData):
         .. [2] http://xpdb.nist.gov/enzyme_thermodynamics/
 
         """
-        tecr_df = self.quilt_pkg.data.TECRDB().copy()
+        tecr_df = pd.read_csv(tecr_file)
 
         # assume a default ionic strength of 0.25 M
         tecr_df.ionic_strength.fillna(0.25, inplace=True)
@@ -488,7 +481,9 @@ class FullTrainingData(TrainingData):
         )
         return tecr_df
 
-    def read_formations(self) -> Tuple[pd.DataFrame, Set[Compound]]:
+    def read_formations(
+        self, formation_file: BytesIO
+    ) -> Tuple[pd.DataFrame, Set[Compound]]:
         """Read the Formation Energy data from literature.
 
         All the data we have for formation energies from [1-6].
@@ -496,10 +491,7 @@ class FullTrainingData(TrainingData):
         :return: a 2-tuple of the Pandas DataFrame of reactions, and the set
         of compounds that do not decompose into groups.
         """
-        formation_df = (
-            self.quilt_pkg.data.formation_energies_transformed().copy()
-        )
-
+        formation_df = pd.read_csv(formation_file)
         compounds = formation_df["cid"].apply(self.ccache.get_compound)
 
         if pd.isnull(compounds).any():
@@ -543,14 +535,16 @@ class FullTrainingData(TrainingData):
         )
         return formation_df, compounds_that_do_not_decompose
 
-    def read_redox(self) -> Tuple[pd.DataFrame, Set[Compound]]:
+    def read_redox(
+        self, redox_file: BytesIO
+    ) -> Tuple[pd.DataFrame, Set[Compound]]:
         """Read the Reduction potential from literature.
 
         All the reduction potentials we have from [7-14].
 
         :return: a Pandas DataFrame of the redox reactions.
         """
-        redox_df = self.quilt_pkg.data.redox().copy()
+        redox_df = pd.read_csv(redox_file)
 
         for col, unit in [
             ("standard_E_prime", "V"),
